@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2011 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -63,17 +63,10 @@ void AlgoConsole::keyPressEvent(QKeyEvent *event)
     if(event->key() >= 0x20 && event->key() <= 0x7e
        && (event->modifiers() == Qt::NoModifier || event->modifiers() == Qt::ShiftModifier))
 	QTextEdit::keyPressEvent(event);
-#if (QT_VERSION >= 0x040700)
     if(event->key() == Qt::Key_Backspace
        && event->modifiers() == Qt::NoModifier
        && textCursor().positionInBlock() > prompt.length())
 	QTextEdit::keyPressEvent(event);
-#else
-    if(event->key() == Qt::Key_Backspace
-       && event->modifiers() == Qt::NoModifier
-       && (textCursor().position()-textCursor().block().position()> prompt.length()))
-	QTextEdit::keyPressEvent(event);
-#endif
     if(event->key() == Qt::Key_Return && event->modifiers() == Qt::NoModifier)
 	onEnter();
     if(event->key() == Qt::Key_Enter)
@@ -82,17 +75,10 @@ void AlgoConsole::keyPressEvent(QKeyEvent *event)
 
 void AlgoConsole::onEnter()
 {
-#if (QT_VERSION >= 0x040700)
     if(textCursor().positionInBlock() == prompt.length())
     {
 	return;
     }
-#else
-    if(textCursor().position()-textCursor().block().position() == prompt.length())
-    {
-	return;
-    }
-#endif
     answer = textCursor().block().text().mid(prompt.length());
     isLocked = true;
     textCursor().insertBlock();
