@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2010 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2017 by Pascal Brachet                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,8 +28,8 @@ class AlgoHighlighter : public QSyntaxHighlighter
 public:
     AlgoHighlighter(QTextDocument *parent = 0);
     ~AlgoHighlighter();
-    QColor ColorStandard, ColorComment, ColorBloc, ColorCommande, ColorSi, ColorTantQue, ColorPour;
-    QStringList BlocWords,SiWords,TantQueWords,PourWords, CommandeWords;
+    QColor ColorStandard, ColorComment, ColorBloc, ColorCommande, ColorSi, ColorTantQue, ColorPour, ColorFonction;
+    QStringList BlocWords,SiWords,TantQueWords,PourWords, CommandeWords,FonctionWords;
 private :
 bool isWordSeparator(QChar c) const;
 bool isSpace(QChar c) const;
