@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2010 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2017 by Pascal Brachet                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -11,24 +11,31 @@
 #ifndef ALGOWEBVIEW_H
 #define ALGOWEBVIEW_H
 
-//#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-//#include "QtWebKitWidgets/qwebview.h"
-//#else
-#include <QWebView>
-//#endif
 
-class AlgoWebView : public QWebView
+#include <QWebEngineView>
+#include <QFileSystemWatcher>
+
+
+class AlgoWebView : public QWebEngineView
 {
     Q_OBJECT
  
 public:
     AlgoWebView(QWidget *parent = 0);
     ~AlgoWebView();
+private:
+QString pdffichier;
+QFileSystemWatcher *file_watcher;
 protected:
     void contextMenuEvent(QContextMenuEvent *event);
+protected slots:
+    void finishLoading(bool);
 public slots:
-void imprimer();
 void exporterPdf();
+private slots:
+void voirPdf(QString);
+
+
 };
 
 
