@@ -1,6 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2010 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2009-2017 by Pascal Brachet                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,11 +14,8 @@
 #include <QMainWindow>
 #include <QLineEdit>
 #include <QPushButton>
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-#include "QtWebKitWidgets/qwebview.h"
-#else
-#include <QWebView>
-#endif
+#include <QWebEngineView>
+
 
 
 class Browser : public QMainWindow
@@ -38,10 +34,11 @@ private slots:
   void Print();
   void Chercher();
 private:
-    QWebView *view;
+    QWebEngineView *view;
     int progress;
     QLineEdit *searchLineEdit;
     QPushButton *findButton;
+    QString pdffichier;
 };
 
 #endif
