@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2010 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2017 by Pascal Brachet                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -10,7 +10,6 @@
 
 #include "browserdialog.h"
 #include <QUrl>
-#include <QWebFrame>
 #include <QTextCursor>
 #include <QTimer>
 #include <QDebug>
@@ -20,13 +19,31 @@
 #include <QMouseEvent>
 #include <QTextCodec>
 #include <QTextStream>
+#include <QWebChannel>
+#include <QSplashScreen>
 
 
 
 BrowserDialog::BrowserDialog(QWidget *parent,QString fichier,bool blackconsole)
     :QDialog( parent)
 {
+hide();
+QPixmap pixmap(400,163);
+if (qApp->devicePixelRatio()>=2)
+{
+pixmap.load(":/images/splash@2x.png");
+pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
+}
+else pixmap.load(":/images/splash.png");
+
+QSplashScreen *splash = new QSplashScreen(pixmap);
+splash->resize(400,163);
+splash->show();
+
 ui.setupUi(this);
+splash->finish(this);
+
+connect(ui.webView, SIGNAL(loadFinished(bool)), SLOT(finishLoading(bool)));
 ui.testerButton->setEnabled(false);
 ui.suivantButton->setEnabled(false);
 ui.stopButton->setEnabled(false);
@@ -79,18 +96,28 @@ ui.textEditPas->setPalette(palette);
 highlighter = new ConsoleHighlighter(ui.textEdit->document(),blackconsole);
 highlighterPas = new LogHighlighter(ui.textEditPas->document(),blackconsole);
 
+ui.pdfButton->setEnabled(false);
+ui.checkBoxPasAPas->setEnabled(false);
+ui.suivantButton->setEnabled(false);
+ui.stopButton->setEnabled(false);
+ui.testerButton->setEnabled(false);
+
 page=new AlgoWebPage(ui.webView,ui.textEdit);
 ui.webView->setPage(page);
-page->mainFrame()->load(QUrl::fromLocalFile(fichier));
-connect(page->mainFrame(), SIGNAL(javaScriptWindowObjectCleared()),this, SLOT(populateJavaScriptWindowObject()));
+
+QWebChannel *channel = new QWebChannel();
+page->setWebChannel(channel);
+channel->registerObject(QString("BrowserDialog"), this);
+page->load(QUrl::fromLocalFile(fichier));
+ui.textEdit->clear();
+ui.textEditPas->clear();
+//ui.testerButton->setEnabled(true);
 connect(ui.testerButton, SIGNAL(clicked()),this, SLOT(LancerAlgo()));
 connect(ui.suivantButton, SIGNAL(clicked()),this, SLOT(ContinuerPasAPas()));
 connect(ui.stopButton, SIGNAL(clicked()),this, SLOT(StopperPasAPas()));
-connect(ui.imprimerButton, SIGNAL(clicked()),ui.webView, SLOT(imprimer()));
 connect(ui.pdfButton, SIGNAL(clicked()),ui.webView, SLOT(exporterPdf()));
 connect(ui.textEdit, SIGNAL(done()),this, SLOT(setFocus()));
-ui.imprimerButton->setEnabled(false);
-ui.pdfButton->setEnabled(false);
+
 }
 
 BrowserDialog::~BrowserDialog(){
@@ -112,13 +139,6 @@ page->stopaffichage();
 e->accept();
 }
 
-void BrowserDialog::populateJavaScriptWindowObject()
-{
-ui.textEdit->clear();
-ui.textEditPas->clear();
-ui.testerButton->setEnabled(true);
-page->mainFrame()->addToJavaScriptWindowObject("browserDialog", this);
-}
 
 void BrowserDialog::scriptAfficher(QString msg,bool newline)
 {
@@ -166,7 +186,6 @@ void BrowserDialog::scriptLaunched()
 ui.checkBoxPasAPas->setEnabled(false);
 //ui.testerButton->setText(QString::fromUtf8("Exécution en cours"));
 ui.testerButton->setEnabled(false);
-ui.imprimerButton->setEnabled(false);
 ui.pdfButton->setEnabled(false);
 ui.labelProcess->show();
 }
@@ -182,7 +201,7 @@ l.setCodec(codec);
 while (!l.atEnd()) 
 	{
 	ligne=l.readLine();
-	data=page->mainFrame()->evaluateJavaScript("ALGOBOX_AJOUTE_RESULTAT(\""+ligne.trimmed()+"\");");;
+	page->runJavaScript("ALGOBOX_AJOUTE_RESULTAT(\""+ligne.trimmed()+"\");");
 	}
 ui.labelProcess->hide();
 ui.testerButton->setText(QString::fromUtf8("Lancer Algorithme"));
@@ -194,7 +213,6 @@ ui.webView->setFocus();
 QPoint pos(0,0);
 QMouseEvent event(QEvent::MouseButtonPress,pos,Qt::LeftButton, Qt::LeftButton,Qt::NoModifier);
 QApplication::sendEvent(ui.webView, &event);
-ui.imprimerButton->setEnabled(true);
 ui.pdfButton->setEnabled(true);
 }
 
@@ -216,10 +234,10 @@ QTimer::singleShot(100, this, SLOT(ExecuterAlgo()));
 
 void BrowserDialog::ExecuterAlgo()
 {
-ui.textEdit->insertPlainText(QString::fromUtf8("***L'algorithme contient une erreur : impossible de le lancer***\n***Vérifiez la syntaxe des affectations et des conditions***\n"));  
-QVariant data;
-if (ui.checkBoxPasAPas->isChecked()) data=page->mainFrame()->evaluateJavaScript("ALGOBOX_ALGO(true);");
-else data=page->mainFrame()->evaluateJavaScript("ALGOBOX_ALGO(false);");
+ui.textEdit->insertPlainText(QString::fromUtf8("***Lancement de l'algorithme***"));
+//ui.textEdit->insertPlainText(QString::fromUtf8("***L'algorithme contient une erreur : impossible de le lancer***\n***Vérifiez la syntaxe des affectations et des conditions***\n"));  
+if (ui.checkBoxPasAPas->isChecked()) page->runJavaScript("ALGOBOX_ALGO(true);");
+else page->runJavaScript("ALGOBOX_ALGO(false);");
 }
 
 void BrowserDialog::ContinuerPasAPas()
@@ -231,9 +249,8 @@ page->continuer();
 void BrowserDialog::StopperPasAPas()
 {
 ui.labelProcess->hide();
-QVariant data;
 if (ui.suivantButton->isEnabled()) page->arreter();
-else data=page->mainFrame()->evaluateJavaScript("ALGOBOX_EMERGENCY_STOP=true;");
+else page->runJavaScript("ALGOBOX_EMERGENCY_STOP=true;");
 }
 
 void BrowserDialog::scriptDebutPause()
@@ -249,3 +266,14 @@ ui.suivantButton->setEnabled(false);
 ui.labelProcess->show();
 //ui.stopButton->setEnabled(false);
 }
+
+void BrowserDialog::finishLoading(bool)
+{
+ui.testerButton->setEnabled(true);
+ui.checkBoxPasAPas->setEnabled(true);
+ui.suivantButton->setEnabled(false);
+ui.stopButton->setEnabled(false);
+ui.pdfButton->setEnabled(true);
+raise();
+show();
+}
