@@ -1,6 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2013 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2009-2017 by Pascal Brachet                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,12 +15,10 @@ QIcon getIcon(QString name)
 QIcon dIcon=QIcon();
 QString base=name.remove(".png");
 dIcon.addFile(base+".png");
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 1, 0))
-if (qApp->devicePixelRatio()==2)
+if (qApp->devicePixelRatio()>=2)
 {
 dIcon.addFile(base+"@2x.png");
 }
-#endif
 return dIcon;
 }
 
